train_track: Train-tracks for freegroup automorphisms
=====================================================

Description
-----------

Train-tracks for freegroup automorphisms

License
-------

GPLv3.0

Upstream Contact
----------------

https://pypi.org/project/train-track/

